@@ -1,11 +1,13 @@
 # this fails immediately on import of ruamel.std.pathlib.blake3 if blake3 not installed
-from blake3 import blake3
+
+from typing import Any
+from blake3 import blake3  # type: ignore
 
 from pathlib import Path
 
 if not hasattr(Path, 'blake3'):
 
-    def _blake3(self, size=-1, timeit=False):
+    def _blake3(self: Path, size: int = -1, timeit: bool = False) -> Any:
         """blake3 hash of the contents
         if size is provided and non-negative only read that amount of bytes from
         the start of the file
@@ -27,4 +29,4 @@ if not hasattr(Path, 'blake3'):
             res = blake3(data, multithreading=True)
         return res
 
-    Path.blake3 = _blake3
+    Path.blake3 = _blake3  # type: ignore
